% Replication code for Optima Debt Maturity Management
%(c) Bigio, Nuno & Passadore model
close all;  clear;
saveit=1; % Save figures if saveit==1

%%  PARAMETERS
% Code parameters
% Tolerance
parameters.tol_path   = 1e-3;  % tolerance parameter optimal path
parameters.tol        = 1e-4;  % tolerance parameter
parameters.max_iter   = 5000;  % maximum number of iterations
parameters.relax      = 0.1 ;  % relaxation coefficient
parameters.relax_path = 0.1;  % relaxation coefficient optimal path
parameters.plot_iter  = 0   ;  % one if you want to plot the iteration

% Numerical parameters
parameters.t_max     = 1000   ; % maximum number of years (time)
parameters.tau_max   = 30    ; % maximum number of years (maturity)
parameters.dt        = 1/12  ; % monthly steps

% Method to Solve the model
parameters.solve_method='iter'; % iter for iterative, solver for solver
parameters.hrss_iter   = parameters.max_iter    ; % 
parameters.hrss_update = 0    ; % change to 0 for Galo's method, 1 for saki's method 
parameters.flag = '0';

% Model parameters
% Time Period annual
% Preference Parameters
parameters.gamma        = 2;      % risk aversion
parameters.rho          = 0.041; % discount factor

% adjustment cost
N_tau=parameters.tau_max/parameters.dt;
maturities     = [3 6 9 12 18 36 60 120 180 360];
parameters.lambda_bar_vec(1:N_tau,1)   = 1e15; % Computer precision. 
time_preallocate;

% Modify Coefficients
parameters.lambda_bar_vec(maturities)    =  1e-2*2*[0.00001 0.00001 0.00001 0.00001 0.00001 8 12 17 40 56];

% Output 
y_ss                    = 1 ; 
parameters.y_ss         = y_ss ; % output at steady state
 
%Interest Rate
auction_premium         = 0;%([0 0 0 0 0 0 14.8+21 42.4+21 74.2+21 70.3+21])*1e-4./maturities/parameters.dt;
inflation               = 0.018;
inflation_end           = 0.023;
parameters.r_bar_ss     = 0.014 - inflation + auction_premium(1);% deterministic steady-state short rate
parameters.delta        = 0.042 - inflation; 

% Number of Shocks
N_r=   2;
N_y=   2;
parameters.N_r=N_r;
parameters.N_y=N_y;

% Default parameters           
parameters.defmodel ='logit'     ; % default model
parameters.muprobit = 2.3;
parameters.phi      = 2;      % Poisson arrival rate
parameters.prob_mat =  [0.95, 0; 0,  0.05]; % NOTE: sum of entries should sum to 1.
parameters.penalty  =  [1,    1; 1   0.02];

% % Output parameters RSS
parameters.y_0(2,1)       = 0.95 *y_ss        ;  % initial value, output after a shock
parameters.rho_y(2,1)     = (1-0.95)*4  ;  % persistence output after shock - 0.95 in quarterly data
parameters.r_bar_0(1,1)   = 0.056 - inflation_end   + auction_premium(1)   ;  % initial value volatility of 0.048 quarterly
% s> changed persistence
parameters.rho_r_bar(1,1) = (1-0.9999)*4;  % persistence (in years)
parameters.y_0(1,1)       = y_ss         ;  % initial value, output after a shock
parameters.rho_y(1,1)     = (1-0.95)*4  ;  % persistence output after shock - 0.95 in quarterly data
parameters.r_bar_0(2,1)   = parameters.r_bar_ss;  % initial value volatility of 0.048 quarterly
parameters.rho_r_bar(2,1) = (1-0.95)*4  ;  % persistence (in years)

% Price of Risk
parameters.U         =  @(c) (c.^(1-parameters.gamma)-1)/(1-parameters.gamma);
parameters.U_p_ratio =  @(c_a,c_b) (c_a/c_b).^(-parameters.gamma);
parameters.dU        =  @(c) (c.^(-parameters.gamma));

% Data
inflation_ss            = [0.018 0.018 0.018 0.018 0.018 0.019 0.020 0.021 0.022 0.023];                % Spanish inflation curve
curve_ss                = [0.027 0.033 0.038 0.041 0.045 0.049 0.050 0.051 0.052 0.052] - inflation_ss + auction_premium; % Spanish yield curve
curve_fr                = [0.021 0.027 0.031 0.034 0.037 0.041 0.042 0.043 0.043 0.044]- inflation_ss + auction_premium; % French yield curve
issuances               = [0.91  1.16  2.31  3.32  1.33  1.75  2.01  2.62  0.77  0.63]*1e-2;  % Issuances over yearly GDP

% Exogenous Issuances
parameters.Exo_Iota             = 0*parameters.lambda_bar_vec;
parameters.Exo_Iota(maturities) = [0.91  1.16  2.31  3.32  1.33  0  0  0  0 0]'/dt/100;

% PLOT RSS OBJECTS
parameters.mode = 'rss'; 
execute_codes
if saveit==1
    save baseline;
end
% PLOT_Yield_curve;
% PLOT_RSS_Objects;

f_init=path_out.rss.f_rss;

%% ADDING AN EXTRA BOND
% First reducing rates
parameters.rho          = parameters.rho -0.01; % discount factor
parameters.r_bar_0(1,1)   = parameters.r_bar_0(1,1) -0.012   ;  % initial value volatility of 0.048 quarterly
% parameters.mode = 'rss'; 
% execute_codes
% if saveit==1
%      save lower_rates;
% end
%f_init=path_out.rss.f_rss;


% Then adding the bond
old_lambda           = parameters.lambda_bar_vec(maturities);
parameters.tau_max   = 50    ; % maximum number of years (maturity)
maturities           = [3 6 9 12 18 36  60 120 180 360 parameters.tau_max *12];
N_tau                = parameters.tau_max/parameters.dt;
time_preallocate;
parameters.lambda_bar_vec(1:N_tau,1)   = 1e15; % Computer precision.
parameters.lambda_bar_vec(maturities)  = (2.6e-2 .* (tau(maturities)>1)+1.6e-2 *tau(maturities)) *2;
parameters.lambda_bar_vec(maturities(1:end-1))    =  1e-2*2*[0.00001 0.00001 0.00001 0.00001 0.00001 8 12 17 40 56];
adjustment           = parameters.lambda_bar_vec(maturities(end))/(parameters.lambda_bar_vec(maturities(end)) + 1/(sum(1./old_lambda) ));
parameters.lambda_bar_vec(maturities) = parameters.lambda_bar_vec(maturities) /adjustment;
parameters.Exo_Iota             = 0*parameters.lambda_bar_vec;
parameters.Exo_Iota(maturities) = [0.91  1.16  2.31  3.32  1.33  0  0  0  0 0 0]'/dt/100;

parameters.mode = 'rss'; 
execute_codes
if saveit==1
     save extra_bond;
end

% Computing a transition - can be used also to compute transitions on rates
f_aux=zeros(N_tau,1);
f_aux(1:length(f_init))=f_init;
f_init=f_aux;
parameters.t_max     = 300   ; % maximum number of years (time)
parameters.mode = 'hr_trans';
parameters.shock = 'y';
% Bi true shock, it is a transition
parameters.hr.y_0(1:N_y,1)        = 1*y_ss       ;  % initial value, output after a shock
parameters.hr.rho_y(1:N_y,1)      = (1-0.95)*4  ;  % persistence output after shock - 0.95 in quarterly data
parameters.hr.r_bar_0(1:N_r,1)    = parameters.r_bar_ss       ;  % initial value volatility of 0.048 quarterly
parameters.hr.rho_r_bar(1:N_r,1)  = (1-0.95)*4  ;  % persistence (in years)

execute_codes
 if saveit==1
      save hrr_extrabond_transition;
 %    save hrr_lower_rate_transition;
 end
 PLOT_extra_bond
 PLOT_HRSS_Transition;

%% PLOT HRSS OBJECTS
% parameters.mode = 'hr';
% parameters.shock = 'y';
% % Income shocks to the homothetic HRSS
% parameters.hr.y_0(1:N_y,1)        = 0.99*y_ss       ;  % initial value, output after a shock
% parameters.hr.rho_y(1:N_y,1)      = (1-0.95)*4  ;  % persistence output after shock - 0.95 in quarterly data
% parameters.hr.r_bar_0(1:N_r,1)    = parameters.r_bar_ss       ;  % initial value volatility of 0.048 quarterly
% parameters.hr.rho_r_bar(1:N_r,1)  = (1-0.95)*4  ;  % persistence (in years)
% 
% execute_codes
%  if saveit==1
%      save hrr_income;
%  end
% 
% % % Rate shocks to the homothetic HRSS
% parameters.mode = 'hr';
% parameters.shock = 'r';
% parameters.hr.y_0(1:N_y,1)        = y_ss       ;  % initial value, output after a shock
% parameters.hr.rho_y(1:N_y,1)      = (1-0.95)*4  ;  % persistence output after shock - 0.95 in quarterly data
% parameters.hr.r_bar_0(1:N_r,1)    = parameters.r_bar_ss   + 0.001    ;  % initial value volatility of 0.048 quarterly
% parameters.hr.rho_r_bar(1:N_r,1)  = (1-0.95)*4  ;  % persistence (in years)
% 
% execute_codes
%  if saveit==1
%      save hrr_rates;
%  end
%  PLOT_IRFS
%  
% %%  A bond expires at time tn
% parameters.mode = 'hr';
% parameters.flag = '2';
% parameters.t_n  = 10/parameters.dt;
% parameters.impulse_n       = -0.1;
% parameters.shock = 'y';
% parameters.hr.y_0(1:N_y,1)        = 1       ;  % initial value, output after a shock
% parameters.hr.rho_y(1:N_y,1)      = (1-0.95)*4  ;  % persistence output after shock - 0.95 in quarterly data
% parameters.hr.r_bar_0(1:N_r,1)    = parameters.r_bar_ss ;  % initial value volatility of 0.048 quarterly
% parameters.hr.rho_r_bar(1:N_r,1)  = (1-0.95)*4  ;  % persistence (in years)
% 
% execute_codes
% if saveit==1
%      save hrr_bond;
% end
% PLOT_Bond
