% PLOTTING IRFS

% INCOME SHOCK
load baseline;
c_init = path_out.rss.c_rss;
i_init = sum(results.iota_rss*dt);
matu      = [36 60 120 180 360];
WAM_init = sum(results.iota_rss(matu).*tau(matu)'*dt)/sum(results.iota_rss(matu)*dt);

load hrr_lower_rate_transition
c_low    = results.c_n;
Issu_low =  sum(results.iota_n(:,:))*dt;
matu      = [36 60 120 180 360];
WAM_low  = zeros(size(c_low));
for i=1:length(t)
    WAM_low(i) = sum(results.iota_n(matu,i).*tau(matu)'*dt)/sum(results.iota_n(matu,i)*dt);
end

load hrr_extrabond_transition
% % Parameters
font_size   = 20;
line_width  =2.5;
base_color  = [0.2 0.2 0.6];

pre_t       = -5;
pos_t       = 200;

if  parameters.shock == 'r'
    color_base2=[0    0.2    0.7];
    LineStyle_2 = '-.';
else
    color_base2=[0    0.2    0.7];
    LineStyle_2 = '-';
end

LineStyle = '-.';
color_base =[ 0.8 0.1 0.1]; 
color1   =  [0.1 0.1 0.1];
color2   =  [0.5 0.5 0.5];
color3   =  [0.9 0.9 0.9];
color4   =  [0.8 0.8 0.9];
color_mat=  [color1; color2; color3; color4];
color_base3=[0.5 0.7 0.1];


color_rss=  [0.6 0.1 0.1];
color_rss_val=  color_base2;
markersize   = 40;
LineStyle_3 = ':';
LineStyle_4 = '-.';

% Variables
dt = parameters.dt;
t         = 0:parameters.dt:parameters.t_max;    % calendar time
Debt_hrss = sum(results.f_hrss)*dt; % 
Debt      = sum(results.f_n(:,:))*dt;
Issuances =  sum(results.iota_n(:,:))*dt;
Issuances_hrss = sum(results.iota_hrss)*dt; %
matu      = [36 60 120 180 360 parameters.tau_max *12];
WAM_iota_hrss = sum(results.iota_hrss(matu).*tau(matu)'*dt)/sum(results.iota_hrss(matu)*dt);
WAM_iota = zeros(size(Debt));
for i=1:length(t)
    WAM_iota(i) = sum(results.iota_n(matu,i).*tau(matu)'*dt)/sum(results.iota_n(matu,i)*dt);
end


fig4 = figure(4);
plot(t,results.c_n,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
scatter(0,c_init,markersize,color_base3,'o','filled'); 
scatter(t(end),results.c_n(end),markersize,color_base2,'>','filled');
plot([pre_t 0],[c_init c_init],'Linewidth',line_width,'Color',color_base3);
scatter(0,c_init,markersize,color_base3,'o');
%plot(0,c_init,'*','Linewidth',4,'Color',color_rss_val,'MarkerSize',2);
grid on; xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex');
scatter(0,results.c_n(1),markersize,color_base2,'o','filled');

plot(t,c_low,'Linewidth',line_width,'Color',color_base,'LineStyle',LineStyle); hold on;
scatter(t(end),c_low(end),markersize,color_base,'>','filled');
scatter(0,c_low(1),markersize,color_base,'o','filled');
text(100,0.96,'+ 50-year bond','FontSize',font_size,'interpreter','latex','Color',color_base2)
text(50,0.975,'Lower rates','FontSize',font_size,'interpreter','latex','Color',color_base)

%title('Expenditure, $c_t$','FontSize',font_size,'interpreter','latex');
xlim([pre_t pos_t]); 
set(gca,'FontSize',20)
orient(fig4,'landscape')
print('extra_bond_expend.pdf', '-dpdf','-r800','-fillpage') 

%%
fig5 = figure(5);
plot(t,Issuances*100,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
plot([pre_t 0],[i_init i_init]*100,'Linewidth',line_width,'Color',color_base3);
scatter(0,i_init*100,markersize,color_base3,'o');
plot(0,i_init*100,'*','Linewidth',line_width,'Color',color_base3,'MarkerSize',2);
scatter(0,Issuances(1)*100,markersize,color_base2,'o','filled'); 
scatter(t(end),Issuances(end)*100,markersize,color_base2,'>','filled'); 

plot(t,Issu_low*100,'Linewidth',line_width,'Color',color_base,'LineStyle',LineStyle); hold on;
scatter(0,Issu_low(1)*100,markersize,color_base,'o','filled'); 
scatter(t(end),Issu_low(end)*100,markersize,color_base,'>','filled'); 

xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex')
ylabel('$\%$ $y_{ss}$','FontSize',font_size,'interpreter','latex')
%title('Issuances','FontSize',font_size,'interpreter','latex')
hold on; xlim([pre_t pos_t]); grid on;
set(gca,'FontSize',20)
orient(fig5,'landscape')
print('extra_bond_issua.pdf', '-dpdf','-r800','-fillpage')

%%
%
fig6 = figure(6);
plot(t,WAM_iota,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
plot([pre_t 0],[WAM_init WAM_init],'Linewidth',line_width,'Color',color_base3);
scatter(0,WAM_init,markersize,color_base3,'o');
plot(0,WAM_init,'*','Linewidth',line_width,'Color',color_base3,'MarkerSize',2);
scatter(0,WAM_iota(1),markersize,color_base2,'o','filled');
scatter(t(end),WAM_iota(end),markersize,color_base2,'>','filled');

plot(t,WAM_low,'Linewidth',line_width,'Color',color_base,'LineStyle',LineStyle); hold on;
scatter(0,WAM_low(1),markersize,color_base,'o','filled');
scatter(t(end),WAM_low(end),markersize,color_base,'>','filled');


xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex')
ylabel('Years','FontSize',font_size,'interpreter','latex')
%title('Weighted average maturity','FontSize',font_size,'interpreter','latex')
hold on; xlim([pre_t pos_t]); grid on;
set(gca,'FontSize',20)
orient(fig6,'landscape')
print('extra_bond_WAM.pdf', '-dpdf','-r800','-fillpage')




%% COMPUTING WELFARE
load hrr_extrabond_transition
V_post   = sum(phi*parameters.prob_mat(:).*path_out.Phi(:).*path_out.V);
% crss     = path_out.rss.c_rss .* ones(size(results.c_n));
% VRSS     = sum(exp(-(parameters.rho+parameters.phi)*t).*(parameters.U(crss)+V_post)*dt);
V0       = sum(exp(-(parameters.rho+parameters.phi)*t).*(parameters.U(results.c_n)+V_post)*dt);

load baseline;
V_post   = sum(phi*parameters.prob_mat(:).*path_out.Phi(:).*path_out.V);
crss     = path_out.rss.c_rss .* ones(size(results.c_n));
VRSS     = sum(exp(-(parameters.rho+parameters.phi)*t).*(parameters.U(crss)+V_post)*dt);

