% PLOTTING IRFS

% INCOME SHOCK
load hrr_income

% % Parameters
font_size   = 25;
line_width  =3;
base_color  = [0.2 0.2 0.6];

pre_t       = -5;
pos_t       = 30;

if  parameters.shock == 'r'
    color_base2=[0.6 0.1 0.1];
    LineStyle_2 = '-.';
else
    color_base2=[0.2 0.1 0.8];
    LineStyle_2 = '-';
end

color_base =[0.1 0.1 0.6]; 
color1   =  [0.1 0.1 0.1];
color2   =  [0.5 0.5 0.5];
color3   =  [0.9 0.9 0.9];
color4   =  [0.8 0.8 0.9];
color_mat=  [color1; color2; color3; color4];



color_rss=  [0.6 0.1 0.1];
color_rss_val=  color_base2;
markersize   = 40;
LineStyle_3 = ':';
LineStyle_4 = '-.';

% Variables
dt = parameters.dt;
t         = 0:parameters.dt:parameters.t_max;    % calendar time
Debt_hrss = sum(results.f_hrss)*dt; % 
Debt      = sum(results.f_n(:,:))*dt;
Issuances =  sum(results.iota_n(:,:))*dt;
Issuances_hrss = sum(results.iota_hrss)*dt; % 

% Elasticities
E_iota_0=(results.iota_n(:,1)./results.iota_hrss-1);
figure
plot(tau,E_iota_0); title('Issuance Elasticities');
iota_hrss=results.iota_hrss;
WAM_rss=tau*iota_hrss/sum(iota_hrss);
iota_0=results.iota_n(:,1);
WAM_0=tau*iota_0/sum(iota_0);

figure;
bar([iota_hrss([36 360]) iota_0([36 360])]);

biWAM_rss=sum(36*iota_hrss(36)+360*iota_hrss(360))/sum(iota_hrss([36 360]));
biWAM_0=sum(36*iota_0(36)+360*iota_0(360))/sum(iota_0([36 360]));


% WAM
maturities=[36 60 120 180 360];
WAM_iota_hrss = tau(maturities)*results.iota_hrss(maturities)/sum(results.iota_hrss(maturities));
WAM_iota = zeros(size(Debt));
for i=1:length(t)
    WAM_iota(i) = tau(maturities)*results.iota_n(maturities,i)/sum(results.iota_n(maturities,i));
end

% [average_duration, average_term_to_maturity] = Portfolio_duration(results, parameters, paths);
exo_hr_path_construct;
paths.r_bar_n = r_bar_n(1,:);
paths.y_n     = y_n(1,:);

fig1 = figure(1)
plot(t,paths.r_bar_n*100,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on; 
scatter(0,parameters.r_bar_ss *100,markersize,color_base2,'o');
plot([pre_t 0],[parameters.r_bar_ss  parameters.r_bar_ss ]*100,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2);
plot(0,parameters.r_bar_ss *100,'*','Linewidth',line_width,'Color',color_rss_val,'MarkerSize',2);
scatter(0,paths.r_bar_n(1)*100,markersize,color_base2,'o','filled'); 
scatter(t(end),paths.r_bar_n(end)*100,markersize,color_base2,'>','filled'); 
title('(a) Short-term rate, $r^*_t$','FontSize',font_size,'interpreter','latex')
xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex')
ylabel('$\%$','FontSize',font_size,'interpreter','latex')
xlim([pre_t pos_t]); grid on;
if  parameters.shock == 'r'
    text(7,0.18,'Interest rate shock','FontSize',font_size,'interpreter','latex','Color',color_base2)
    orient(fig1,'landscape')
	print('IRFS_panel_a.pdf', '-dpdf','-r800','-fillpage') 
end

fig2 = figure(2)
plot(t,results.r_n*100,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
scatter(0,parameters.rho*100,markersize,color_base2,'o');
plot([pre_t 0],[parameters.rho parameters.rho]*100,'Linewidth',line_width,'Color',color_base2);
scatter(t(end),results.r_n(end)*100,markersize,color_base2,'>','filled'); 
plot(0,parameters.rho*100,'*','Linewidth',line_width,'Color',color_rss_val,'MarkerSize',2);
scatter(0,results.r_n(1)*100,markersize,color_base2,'o','filled'); 
title('(b) Discount, $r_t$','FontSize',font_size,'interpreter','latex')
xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex')
ylabel('$\%$','FontSize',font_size,'interpreter','latex')
xlim([pre_t pos_t]); grid on;
if  parameters.shock == 'r'
    orient(fig2,'landscape')
	print('IRFS_panel_b.pdf', '-dpdf','-r800','-fillpage') 
end

fig3 = figure(3)
plot(t,paths.y_n,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
scatter(0,paths.y_n(1),markersize,color_base2,'o','filled'); 
scatter(t(end),paths.y_n(end),markersize,color_base2,'>','filled');
plot([pre_t 0],[paths.y_n(end) paths.y_n(end)],'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2);
scatter(0,paths.y_n(end),markersize,color_base2,'o');
plot(0,paths.y_n(end),'*','Linewidth',4,'Color',color_rss_val,'MarkerSize',2);
grid on; xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex');
title('(c) Income, $y_t$','FontSize',font_size,'interpreter','latex');
xlim([pre_t pos_t]); 
if  parameters.shock == 'r'
else
    text(10,0.995,'Income shock','FontSize',font_size,'interpreter','latex','Color',color_base2)
end
if  parameters.shock == 'r'
    orient(fig3,'landscape')
	print('IRFS_panel_c.pdf', '-dpdf','-r800','-fillpage') 
end

fig4 = figure(4)
plot(t,(results.c_n/results.c_n(end)-1)*100,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
scatter(0,(results.c_n(1)/results.c_n(end)-1)*100,markersize,color_base2,'o','filled'); 
scatter(t(end),(results.c_n(end)/results.c_n(end)-1)*100,markersize,color_base2,'>','filled');
plot([pre_t 0],[(results.c_hrss(1)/results.c_n(end)-1)*100 (results.c_hrss(1)/results.c_n(end)-1)*100],'Linewidth',line_width,'Color',color_base2);
scatter(0,(results.c_hrss(1)/results.c_n(end)-1)*100,markersize,color_base2,'o');
plot(0,(results.c_hrss(1)/results.c_n(end)-1)*100,'*','Linewidth',4,'Color',color_rss_val,'MarkerSize',2);
grid on; xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex');
title('(d) Expenditure, $c_t$','FontSize',font_size,'interpreter','latex');
xlim([pre_t pos_t]); 
if  parameters.shock == 'r'
    orient(fig4,'landscape')
	print('IRFS_panel_d.pdf', '-dpdf','-r800','-fillpage') 
end

fig5 = figure(5)
plot(t,Issuances*100,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
plot([pre_t 0],[Issuances_hrss Issuances_hrss]*100,'Linewidth',line_width,'Color',color_base2);
scatter(0,Issuances_hrss*100,markersize,color_base2,'o');
plot(0,Issuances_hrss*100,'*','Linewidth',line_width,'Color',color_rss_val,'MarkerSize',2);
scatter(0,Issuances(1)*100,markersize,color_base2,'o','filled'); 
scatter(t(end),Issuances(end)*100,markersize,color_base2,'>','filled'); 

xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex')
ylabel('$\%$ $y_{ss}$','FontSize',font_size,'interpreter','latex')
title('(e) Issuances','FontSize',font_size,'interpreter','latex')
hold on; xlim([pre_t pos_t]); grid on;
if  parameters.shock == 'r'
    orient(fig5,'landscape')
	print('IRFS_panel_e.pdf', '-dpdf','-r800','-fillpage') 
end

fig6 = figure(6)
plot(t,WAM_iota,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
plot([pre_t 0],[WAM_iota(end) WAM_iota(end)],'Linewidth',line_width,'Color',color_base2);
scatter(0,WAM_iota(end),markersize,color_base,'o');
plot(0,WAM_iota(end),'*','Linewidth',line_width,'Color',color_rss_val,'MarkerSize',2);
scatter(0,WAM_iota(1),markersize,color_base2,'o','filled'); 
scatter(t(end),WAM_iota(end),markersize,color_base2,'>','filled'); 
xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex')
ylabel('Years','FontSize',font_size,'interpreter','latex')
title('(f) Weighted average maturity','FontSize',font_size,'interpreter','latex')
hold on; xlim([pre_t pos_t]); grid on;
if  parameters.shock == 'r'
    orient(fig6,'landscape')
	print('IRFS_panel_f.pdf', '-dpdf','-r800','-fillpage') 
end


%% RATE SHOCK
load hrr_rates
% % Parameters
font_size   = 25;
line_width  =3;
base_color  = [0.2 0.2 0.6];

pre_t       = -5;
pos_t       = 30;

if  parameters.shock == 'r'
    color_base2=[0.6 0.1 0.1];
    LineStyle_2 = '-.';
else
    color_base2=[0.2 0.1 0.8];
    LineStyle_2 = '-';
end

color_base =[0.1 0.1 0.6]; 
color1   =  [0.1 0.1 0.1];
color2   =  [0.5 0.5 0.5];
color3   =  [0.9 0.9 0.9];
color4   =  [0.8 0.8 0.9];
color_mat=  [color1; color2; color3; color4];



color_rss=  [0.6 0.1 0.1];
color_rss_val=  color_base2;
markersize   = 40;
LineStyle_3 = ':';
LineStyle_4 = '-.';

% Variables
dt = parameters.dt;
t         = 0:parameters.dt:parameters.t_max;    % calendar time
Debt_hrss = sum(results.f_hrss)*dt; % 
Debt      = sum(results.f_n(:,:))*dt;
Issuances =  sum(results.iota_n(:,:))*dt;
Issuances_hrss = sum(results.iota_hrss)*dt; % 
WAM_iota_hrss = sum(results.iota_hrss.*tau'*dt)/sum(results.iota_hrss*dt);
% WAM_iota = zeros(size(Debt));
% for i=1:length(t)
%     WAM_iota(i) = sum(results.iota_n(:,i).*tau')/sum(results.iota_n(:,i));
% end
% WAM
maturities=[36 60 120 180 360];
WAM_iota_hrss = tau(maturities)*results.iota_hrss(maturities)/sum(results.iota_hrss(maturities));
WAM_iota = zeros(size(Debt));
for i=1:length(t)
    WAM_iota(i) = tau(maturities)*results.iota_n(maturities,i)/sum(results.iota_n(maturities,i));
end

% Variables


% [average_duration, average_term_to_maturity] = Portfolio_duration(results, parameters, paths);
exo_hr_path_construct;
paths.r_bar_n = r_bar_n(1,:);
paths.y_n     = y_n(1,:);

fig1 = figure(1)
plot(t,paths.r_bar_n*100,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on; 
scatter(0,parameters.r_bar_ss *100,markersize,color_base2,'o');
plot([pre_t 0],[parameters.r_bar_ss  parameters.r_bar_ss ]*100,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2);
plot(0,parameters.r_bar_ss *100,'*','Linewidth',line_width,'Color',color_rss_val,'MarkerSize',2);
scatter(0,paths.r_bar_n(1)*100,markersize,color_base2,'o','filled'); 
scatter(t(end),paths.r_bar_n(end)*100,markersize,color_base2,'>','filled'); 
title('(a) Short-term rate, $r^*_t$','FontSize',font_size,'interpreter','latex')
xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex')
ylabel('$\%$','FontSize',font_size,'interpreter','latex')
xlim([pre_t pos_t]); grid on;
set(gca,'FontSize',20)
if  parameters.shock == 'r'
    text(9,-0.34,'Interest rate shock','FontSize',font_size,'interpreter','latex','Color',color_base2)
    orient(fig1,'landscape')
	print('IRFS_panel_a.pdf', '-dpdf','-r800','-fillpage') 
end

fig2 = figure(2)
plot(t,results.r_n*100,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
scatter(0,parameters.rho*100,markersize,color_base2,'o');
plot([pre_t 0],[parameters.rho parameters.rho]*100,'Linewidth',line_width,'Color',color_base2);
scatter(t(end),results.r_n(end)*100,markersize,color_base2,'>','filled'); 
plot(0,parameters.rho*100,'*','Linewidth',line_width,'Color',color_rss_val,'MarkerSize',2);
scatter(0,results.r_n(1)*100,markersize,color_base2,'o','filled'); 
title('(b) Discount, $r_t$','FontSize',font_size,'interpreter','latex')
xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex')
ylabel('$\%$','FontSize',font_size,'interpreter','latex')
xlim([pre_t pos_t]); grid on;
set(gca,'FontSize',20)
if  parameters.shock == 'r'
    orient(fig2,'landscape')
	print('IRFS_panel_b.pdf', '-dpdf','-r800','-fillpage') 
end

fig3 = figure(3)
plot(t,paths.y_n,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
scatter(0,paths.y_n(1),markersize,color_base2,'o','filled'); 
scatter(t(end),paths.y_n(end),markersize,color_base2,'>','filled');
plot([pre_t 0],[paths.y_n(end) paths.y_n(end)],'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2);
scatter(0,paths.y_n(end),markersize,color_base2,'o');
plot(0,paths.y_n(end),'*','Linewidth',4,'Color',color_rss_val,'MarkerSize',2);
grid on; xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex');
title('(c) Income, $y_t$','FontSize',font_size,'interpreter','latex');
xlim([pre_t pos_t]); 
set(gca,'FontSize',20)
if  parameters.shock == 'r'
else
    text(10,0.995,'Income shock','FontSize',font_size,'interpreter','latex','Color',color_base2)
end
if  parameters.shock == 'r'
    orient(fig3,'landscape')
	print('IRFS_panel_c.pdf', '-dpdf','-r800','-fillpage') 
end

fig4 = figure(4)
plot(t,(results.c_n/results.c_n(end)-1)*100,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
scatter(0,(results.c_n(1)/results.c_n(end)-1)*100,markersize,color_base2,'o','filled'); 
scatter(t(end),(results.c_n(end)/results.c_n(end)-1)*100,markersize,color_base2,'>','filled');
plot([pre_t 0],[(results.c_hrss(1)/results.c_n(end)-1)*100 (results.c_hrss(1)/results.c_n(end)-1)*100],'Linewidth',line_width,'Color',color_base2);
scatter(0,(results.c_hrss(1)/results.c_n(end)-1)*100,markersize,color_base2,'o');
plot(0,(results.c_hrss(1)/results.c_n(end)-1)*100,'*','Linewidth',4,'Color',color_rss_val,'MarkerSize',2);
grid on; xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex');
title('(d) Expenditure, $c_t$','FontSize',font_size,'interpreter','latex');
ylabel('$\%$ RSS expenditure $c_{rss}$','FontSize',font_size,'interpreter','latex')
xlim([pre_t pos_t]); 
set(gca,'FontSize',20)
if  parameters.shock == 'r'
    orient(fig4,'landscape')
	print('IRFS_panel_d.pdf', '-dpdf','-r800','-fillpage') 
end

fig5 = figure(5)
plot(t,Issuances*100,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
plot([pre_t 0],[Issuances_hrss Issuances_hrss]*100,'Linewidth',line_width,'Color',color_base2);
scatter(0,Issuances_hrss*100,markersize,color_base2,'o');
plot(0,Issuances_hrss*100,'*','Linewidth',line_width,'Color',color_rss_val,'MarkerSize',2);
scatter(0,Issuances(1)*100,markersize,color_base2,'o','filled'); 
scatter(t(end),Issuances(end)*100,markersize,color_base2,'>','filled'); 

xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex')
ylabel('$\%$ $y_{ss}$','FontSize',font_size,'interpreter','latex')
title('(e) Issuances','FontSize',font_size,'interpreter','latex')
hold on; xlim([pre_t pos_t]); grid on;
set(gca,'FontSize',20)
if  parameters.shock == 'r'
    orient(fig5,'landscape')
	print('IRFS_panel_e.pdf', '-dpdf','-r800','-fillpage') 
end

fig6 = figure(6)
plot(t,WAM_iota,'Linewidth',line_width,'Color',color_base2,'LineStyle',LineStyle_2); hold on;
plot([pre_t 0],[WAM_iota(end) WAM_iota(end)],'Linewidth',line_width,'Color',color_base2);
scatter(0,WAM_iota(end),markersize,color_base,'o');
plot(0,WAM_iota(end),'*','Linewidth',line_width,'Color',color_rss_val,'MarkerSize',2);
scatter(0,WAM_iota(1),markersize,color_base2,'o','filled'); 
scatter(t(end),WAM_iota(end),markersize,color_base2,'>','filled'); 
xlabel('Time, $t$ (years)','FontSize',font_size,'interpreter','latex')
ylabel('Years','FontSize',font_size,'interpreter','latex')
title('(f) Weighted average maturity','FontSize',font_size,'interpreter','latex')
hold on; xlim([pre_t pos_t]); grid on;
set(gca,'FontSize',20)
if  parameters.shock == 'r'
    orient(fig6,'landscape')
	print('IRFS_panel_f.pdf', '-dpdf','-r800','-fillpage') 
end

