%% ISSUANCES
fig=figure;
set(fig,'defaultLegendAutoUpdate','off');
font_size   = 25;
h=bar([100*results.iota_rss(maturities)'*dt;100*issuances]','EdgeColor','none');
set(gca,'xticklabel',{maturities})
grid
xlabel('Maturity (months)','FontSize',font_size,'interpreter','latex')
ylabel('$\%$ annual GDP ','FontSize',font_size-2,'interpreter','latex')
% title('(a) Issuances','FontSize',font_size,'interpreter','latex')
legend({'Model','Data'},'Box','off','FontSize',font_size,'interpreter','latex','location','best');
line([5.5 5.5],[0 3.5],'Linewidth',2,'color',[ 0.5 0.7 0.1],'linestyle','--')
set(gca,'FontSize',20)
orient(fig,'landscape')
print('RSS_panel_1.pdf', '-dpdf','-r800','-fillpage') 

fig=figure;
set(fig,'defaultLegendAutoUpdate','off');
font_size   = 25;
plot(100*dt*flip(cumsum(flip(results.iota_rss))),'Linewidth',2)
hold on
issuances_data = zeros(size(results.iota_rss));
issuances_data(maturities) = issuances;
f_data = flip(cumsum(flip(issuances_data)));
plot(100*flip(cumsum(flip(issuances_data))),'--','Linewidth',2)
grid
xlabel('Maturity (months)','FontSize',font_size,'interpreter','latex')
ylabel('$\%$  annual GDP ','FontSize',font_size-2,'interpreter','latex')
% title('(b) Debt stock','FontSize',font_size,'interpreter','latex')
xlim([0 360])
ylim([0 20])
set(gca,'FontSize',20)
legend({'Model','Data'},'Box','off','FontSize',font_size,'interpreter','latex','location','best');
line([18 18],[0 20],'Linewidth',2,'color',[ 0.5 0.7 0.1],'linestyle','--')
orient(fig,'landscape')
print('RSS_panel_2.pdf', '-dpdf','-r800','-fillpage') 

%% Additional computations
RSS_issuances  = sum(results.iota_rss(maturities)*dt);
RSS_stock      = dt*sum(flip(cumsum(flip(results.iota_rss))))*dt;
DATA_issuances = sum(issuances);
WAM_debt      = sum(results.f_rss.*tau'*dt)/sum(results.f_rss*dt);
WAM_debt_data = sum(f_data.*tau')/sum(f_data);
WAM_issuances = sum(results.iota_rss.*tau'*dt)/sum(results.iota_rss*dt);
WAM_issuances_data = sum(issuances.*tau(maturities))/sum(issuances);

%% FORCE DECOMPOSITION
font_size   = 18;
% Steady state
psi_rss            = results.psi_rss;
Epsi_0_mat= rss.psi_0_mat*sum(parameters.prob_mat,2);
psi_rss_no_default = solve_HJB_rss(r_bar_ss,Epsi_0_mat,parameters);
psi_ss             = solve_HJB_ss(parameters.r_bar_ss,parameters); % compute steady-state prices
steady=solve_steady(psi_ss,parameters)            ;            % compute steady-state objects
SS_stock_debt  = sum(steady.f_ss*parameters.dt);
SS_issuances   = sum(steady.iota_ss*parameters.dt);
lambda_backup  = parameters.lambda_bar_vec;
lambda_hom     = fzero(@(lambda) lambda_fit(lambda,psi_rss_no_default,parameters, RSS_issuances,maturities),2*20e-2);%2*28e-2);
parameters.lambda_bar_vec = lambda_backup;
%prices without default
ii=0;
v_0_mat=zeros(N_tau,1);
v_0_mat_no_echo =zeros(N_tau,1);
v_0_mat_no_default =zeros(N_tau,1);
v_0_mat_no_self_insurance=zeros(N_tau,1);
c_0           = path_out.c_out(:,2);
for rr=1:N_r
    for yy=1:N_y
        ii=1+ii;
        v_0 = results.v_n(:,1,ii)                                     ;
        v_0_mat                   = v_0_mat                  +parameters.prob_mat(rr,yy)*rss.a(ii)*v_0*parameters.U_p_ratio(c_0(ii),results.c_rss(ii));
        v_0_mat_no_echo           = v_0_mat_no_echo          +parameters.prob_mat(rr,yy)*rss.Phi(ii)*v_0*parameters.U_p_ratio(c_0(ii),results.c_rss(ii));
        v_0_mat_no_default        = v_0_mat_no_default       +parameters.prob_mat(rr,yy)*v_0*parameters.U_p_ratio(c_0(ii),results.c_rss(ii));
        v_0_mat_no_self_insurance = v_0_mat_no_self_insurance+parameters.prob_mat(rr,yy)*v_0;
    end
end
v_rss                        = results.v_rss;
v_rss_check                  = solve_HJB_rss(parameters.rho,v_0_mat,parameters);
v_rss_no_echo                = solve_HJB_rss(parameters.rho,v_0_mat_no_echo,parameters);
v_rss_no_default             = solve_HJB_rss(parameters.rho,v_0_mat_no_default,parameters);
v_rss_no_self_insurance      = solve_HJB_rss(parameters.rho,v_0_mat_no_self_insurance,parameters);   
v_dss                        = steady.v_ss;

iss_impatience               = (1-v_dss./psi_ss)./lambda_hom; % v_DSS
iss_curve                    = (1-v_dss./psi_rss_no_default)./lambda_hom; % v_DSS
iss_hedging                  = (1-v_rss_no_self_insurance./psi_rss_no_default)./lambda_hom; % with hedging
iss_self_ins                 = (1-v_rss_no_default./psi_rss_no_default)./lambda_hom; % with self ins
iss_default                  = (1-v_rss_no_echo./psi_rss)./lambda_hom; % with default
iss_lambda                   = (1-v_rss./psi_rss)./lambda_hom; % lambda heterogeneous
iss_rss                      = results.iota_rss; % RSS


fig=figure;  % 3 years bond
mat  = 12*30; % 
data = [iss_impatience(mat) iss_curve(mat) iss_hedging(mat) iss_self_ins(mat) iss_default(mat) iss_lambda(mat) iss_rss(mat) ]*dt;
white = zeros(8,1); 
blue = zeros(8,1); 
blue(1)  = data(1);
blue(end) = data(end) ;
for i =2:length(blue)-1
    if data(i)>data(i-1)
        blue(i) = data(i)-data(i-1);
        white(i) = data(i-1);
    else
        blue(i) = data(i-1)-data(i);
        white(i) = data(i);
    end  
end

b=bar([100*white';100*blue']','stacked','EdgeColor','none');
b(1,1).FaceColor = [ 1 1 1];
b(1,2).FaceColor = [0    0.4470+0.25    0.7410+0.25];
set(gca,'xticklabel',{[]})
font_size   = 25;
ylabel('$\%$ annual GDP ','FontSize',font_size-2,'interpreter','latex')
% title('3-year bond','FontSize',font_size,'interpreter','latex')
font_size   = 20;
patch([0.6 0.6 2.4 2.4],[100*(white(1)+blue(1)) 100*(white(1)+blue(1)) 100*(white(1)+blue(1)) 100*(white(1)+blue(1))],'blue')
patch([1.6 1.6 3.4 3.4],[100*(white(2)) 100*(white(2)) 100*(white(2)) 100*(white(2))],'blue')
patch([2.6 2.6 4.4 4.4],[100*(white(3)+blue(3)) 100*(white(3)+blue(3)) 100*(white(3)+blue(3)) 100*(white(3)+blue(3))],'blue')
patch([3.6 3.6 5.4 5.4],[100*(white(4)+blue(4)) 100*(white(4)+blue(4)) 100*(white(4)+blue(4)) 100*(white(4)+blue(4))],'blue')
patch([4.6 4.6 6.4 6.4],[100*(white(5)) 100*(white(5)) 100*(white(5)) 100*(white(5))],'blue')
patch([5.6 5.6 7.4 7.4],[100*(white(6)) 100*(white(6)) 100*(white(6)) 100*(white(6))],'blue')
patch([6.6 6.6 8.4 8.4],[100*(white(7)) 100*(white(7)) 100*(white(7)) 100*(white(7))],'blue')
%ylim([0 2])
shift= 1;
h=text(7+shift,100*(white(8)+blue(8))+0.1,'Baseline','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(6+shift,100*(white(7)+blue(7))+0.1,'Het. liquidity','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(5+shift,100*(white(6)+blue(6))+0.1,'Echo effect','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(4+shift,100*(white(5)+blue(5))+0.1,'Credit risk','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(3+shift,100*(white(4)+blue(4))+0.1,'Self-insurance','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(2+shift,100*(white(3)+blue(3))+0.1,'Hedging','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(1+shift,100*(white(2)+blue(2))+0.1,'Yield curve','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(0+shift,100*(white(1)+blue(1))+0.1,'Impatience','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
set(gca,'FontSize',20)
orient(fig,'landscape')
print('forces_panel_1.pdf', '-dpdf','-r800','-fillpage') 
%%
% fig=figure;  % 5 year bond
% mat  = 1*12; % 
% data = [iss_impatience(mat) iss_curve(mat) iss_lambda(mat) iss_hedging(mat) iss_self_ins(mat) iss_default(mat) iss_rss(mat) ]*dt;
% white = zeros(8,1); 
% blue = zeros(8,1); 
% blue(1)  = data(1);
% blue(end) = data(end) ;
% for i =2:length(blue)-1
%     if data(i)>data(i-1)
%         blue(i) = data(i)-data(i-1);
%         white(i) = data(i-1);
%     else
%         blue(i) = data(i-1)-data(i);
%         white(i) = data(i);
%     end  
% end
% 
% b=bar([100*white';100*blue']','stacked','EdgeColor','none');
% b(1,1).FaceColor = [ 1 1 1];
% b(1,2).FaceColor = [0    0.4470+0.25    0.7410+0.25];
% set(gca,'xticklabel',{[]})
% ylabel('$\%$ annual GDP ','FontSize',font_size-2,'interpreter','latex')
% title('(b) 5-year bond','FontSize',font_size,'interpreter','latex')
% patch([0.6 0.6 2.4 2.4],[100*(white(1)+blue(1)) 100*(white(1)+blue(1)) 100*(white(1)+blue(1)) 100*(white(1)+blue(1))],'blue')
% patch([1.6 1.6 3.4 3.4],[100*(white(2)) 100*(white(2)) 100*(white(2)) 100*(white(2))],'blue')
% patch([2.6 2.6 4.4 4.4],[100*(white(3)+blue(3)) 100*(white(3)+blue(3)) 100*(white(3)+blue(3)) 100*(white(3)+blue(3))],'blue')
% patch([3.6 3.6 5.4 5.4],[100*(white(4)+blue(4)) 100*(white(4)+blue(4)) 100*(white(4)+blue(4)) 100*(white(4)+blue(4))],'blue')
% patch([4.6 4.6 6.4 6.4],[100*(white(5)) 100*(white(5)) 100*(white(5)) 100*(white(5))],'blue')
% patch([5.6 5.6 7.4 7.4],[100*(white(6)) 100*(white(6)) 100*(white(6)) 100*(white(6))],'blue')
% patch([6.6 6.6 8.4 8.4],[100*(white(7)) 100*(white(7)) 100*(white(7)) 100*(white(7))],'blue')
% %ylim([0 10])
% shift= 1;
% h=text(7+shift,100*(white(8)+blue(8))+0.1,'Baseline','FontSize',font_size-2,'interpreter','latex');
% set(h,'Rotation',90);
% h=text(6+shift,100*(white(7)+blue(7))+0.1,'Echo effect','FontSize',font_size-2,'interpreter','latex');
% set(h,'Rotation',90);
% h=text(5+shift,100*(white(6)+blue(6))+0.1,'Credit risk','FontSize',font_size-2,'interpreter','latex');
% set(h,'Rotation',90);
% h=text(4+shift,100*(white(5)+blue(5))+0.1,'Self-insurance','FontSize',font_size-2,'interpreter','latex');
% set(h,'Rotation',90);
% h=text(3+shift,100*(white(4)+blue(4))+0.1,'Hedging','FontSize',font_size-2,'interpreter','latex');
% set(h,'Rotation',90);
% h=text(2+shift,100*(white(3)+blue(3))+0.1,'Het. liquidity','FontSize',font_size-2,'interpreter','latex');
% set(h,'Rotation',90);
% h=text(1+shift,100*(white(2)+blue(2))+0.1,'Yield curve','FontSize',font_size-2,'interpreter','latex');
% set(h,'Rotation',90);
% h=text(0+shift,100*(white(1)+blue(1))+0.1,'Impatience','FontSize',font_size-2,'interpreter','latex');
% set(h,'Rotation',90);
% orient(fig,'landscape')
% print('forces_panel_2.pdf', '-dpdf','-r800','-fillpage') 
%%

fig=figure;  % 10 years bond
mat  = 12*10; % 
data = [iss_impatience(mat) iss_curve(mat) iss_lambda(mat) iss_hedging(mat) iss_self_ins(mat) iss_default(mat) iss_rss(mat) ]*dt;
white = zeros(8,1); 
blue = zeros(8,1); 
blue(1)  = data(1);
blue(end) = data(end) ;
for i =2:length(blue)-1
    if data(i)>data(i-1)
        blue(i) = data(i)-data(i-1);
        white(i) = data(i-1);
    else
        blue(i) = data(i-1)-data(i);
        white(i) = data(i);
    end  
end

b=bar([100*white';100*blue']','stacked','EdgeColor','none');
b(1,1).FaceColor = [ 1 1 1];
b(1,2).FaceColor = [0    0.4470+0.25    0.7410+0.25];
set(gca,'xticklabel',{[]})
font_size   = 25;
ylabel('$\%$ annual GDP ','FontSize',font_size-2,'interpreter','latex')
% title('10-year bond','FontSize',font_size,'interpreter','latex')
font_size   = 20;
patch([0.6 0.6 2.4 2.4],[100*(white(1)+blue(1)) 100*(white(1)+blue(1)) 100*(white(1)+blue(1)) 100*(white(1)+blue(1))],'blue')
patch([1.6 1.6 3.4 3.4],[100*(white(2)) 100*(white(2)) 100*(white(2)) 100*(white(2))],'blue')
patch([2.6 2.6 4.4 4.4],[100*(white(3)+blue(3)) 100*(white(3)+blue(3)) 100*(white(3)+blue(3)) 100*(white(3)+blue(3))],'blue')
patch([3.6 3.6 5.4 5.4],[100*(white(4)+blue(4)) 100*(white(4)+blue(4)) 100*(white(4)+blue(4)) 100*(white(4)+blue(4))],'blue')
patch([4.6 4.6 6.4 6.4],[100*(white(5)) 100*(white(5)) 100*(white(5)) 100*(white(5))],'blue')
patch([5.6 5.6 7.4 7.4],[100*(white(6)) 100*(white(6)) 100*(white(6)) 100*(white(6))],'blue')
patch([6.6 6.6 8.4 8.4],[100*(white(7)) 100*(white(7)) 100*(white(7)) 100*(white(7))],'blue')
ylim([0 10])
shift= 1;
h=text(7+shift,100*(white(8)+blue(8))+0.1,'Baseline','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(6+shift,100*(white(7)+blue(7))+0.1,'Echo effect','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(5+shift,100*(white(6)+blue(6))+0.1,'Credit risk','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(4+shift,100*(white(5)+blue(5))+0.1,'Self-insurance','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(3+shift,100*(white(4)+blue(4))+0.1,'Hedging','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(2+shift,100*(white(3)+blue(3))+0.1,'Het. liquidity','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(1+shift,100*(white(2)+blue(2))+0.1,'Yield curve','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(0+shift,100*(white(1)+blue(1))+0.1,'Impatience','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);orient(fig,'landscape')
set(gca,'FontSize',20)
print('forces_panel_3.pdf', '-dpdf','-r800','-fillpage') 
%%

fig=figure;  % 30 years bond
mat  = 12*30; % 
data = [iss_impatience(mat) iss_curve(mat) iss_lambda(mat) iss_hedging(mat) iss_self_ins(mat) iss_default(mat) iss_rss(mat) ]*dt;
white = zeros(8,1); 
blue = zeros(8,1); 
blue(1)  = data(1);
blue(end) = data(end) ;
for i =2:length(blue)-1
    if data(i)>data(i-1)
        blue(i) = data(i)-data(i-1);
        white(i) = data(i-1);
    else
        blue(i) = data(i-1)-data(i);
        white(i) = data(i);
    end  
end

b=bar([100*white';100*blue']','stacked','EdgeColor','none');
b(1,1).FaceColor = [ 1 1 1];
b(1,2).FaceColor = [0    0.4470+0.25    0.7410+0.25];
set(gca,'xticklabel',{[]})
font_size   = 25;
ylabel('$\%$ annual GDP ','FontSize',font_size-2,'interpreter','latex')
% title('30-year bond','FontSize',font_size,'interpreter','latex')
font_size   = 20;
patch([0.6 0.6 2.4 2.4],[100*(white(1)+blue(1)) 100*(white(1)+blue(1)) 100*(white(1)+blue(1)) 100*(white(1)+blue(1))],'blue')
patch([1.6 1.6 3.4 3.4],[100*(white(2)) 100*(white(2)) 100*(white(2)) 100*(white(2))],'blue')
patch([2.6 2.6 4.4 4.4],[100*(white(3)) 100*(white(3)) 100*(white(3)) 100*(white(3))],'blue')
patch([3.6 3.6 5.4 5.4],[100*(white(4)+blue(4)) 100*(white(4)+blue(4)) 100*(white(4)+blue(4)) 100*(white(4)+blue(4))],'blue')
patch([4.6 4.6 6.4 6.4],[100*(white(5)) 100*(white(5)) 100*(white(5)) 100*(white(5))],'blue')
patch([5.6 5.6 7.4 7.4],[100*(white(6)) 100*(white(6)) 100*(white(6)) 100*(white(6))],'blue')
patch([6.6 6.6 8.4 8.4],[100*(white(7)) 100*(white(7)) 100*(white(7)) 100*(white(7))],'blue')

ylim([0 10])
shift= 1;
h=text(7+shift,100*(white(8)+blue(8))+0.1,'Baseline','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(6+shift,100*(white(7)+blue(7))+0.1,'Echo effect','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(5+shift,100*(white(6)+blue(6))+0.1,'Credit risk','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(4+shift,100*(white(5)+blue(5))+0.1,'Self-insurance','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(3+shift,100*(white(4)+blue(4))+0.1,'Hedging','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(2+shift,100*(white(3)+blue(3))+0.1,'Het. liquidity','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(1+shift,100*(white(2)+blue(2))+0.1-4,'Yield curve','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
h=text(0+shift,100*(white(1)+blue(1))+0.1-4,'Impatience','FontSize',font_size-2,'interpreter','latex');
set(h,'Rotation',90);
orient(fig,'landscape')
set(gca,'FontSize',20)
print('forces_panel_4.pdf', '-dpdf','-r800','-fillpage') 